/*  Copyright (c) MIPoPS. All Rights Reserved.
 *
 *  Use of this source code is governed by a BSD-3-Clause license that can
 *  be found in the LICENSE.txt file in the root of the source tree.
 */

//---------------------------------------------------------------------------
#pragma once
#include <bitset>
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
enum options_t
{
    Option_CaptionPresenceChange,
    Option_Max,
};

//---------------------------------------------------------------------------
enum return_value
{
    ReturnValue_OK = 0,
    ReturnValue_ERROR,
};
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
#define Program_Version "24.07.20260131"
//---------------------------------------------------------------------------
